@@ -20,21 +20,25 @@
 Rcpp.package.skeleton <- function(
 	name = "anRpackage", list = character(), environment = .GlobalEnv,
 	path = ".", force = FALSE, namespace = TRUE,
-	code_files = character(),
+	code_files = character(), cpp_files = character(),
 	example_code = TRUE,
+	attributes = FALSE,
 	module = FALSE,
 	author = "Who wrote it",
 	maintainer = if(missing( author)) "Who to complain to" else author,
 	email = "yourfault@somewhere.net",
 	license = "What Licence is it under ?"
 	){
+	
+	if (!is.character(cpp_files)) 
+		stop("'cpp_files' must be a character vector")
 
 	env <- parent.frame(1)
 
 	if( !length(list) ){
 		fake <- TRUE
 		assign( "Rcpp.fake.fun", function(){}, envir = env )
-		if( example_code ){
+		if( example_code && !isTRUE(attributes)){ 
 			assign( "rcpp_hello_world", function(){}, envir = env )
 			remove_hello_world <- TRUE
 		} else {
@@ -59,7 +63,7 @@ Rcpp.package.skeleton <- function(
 	call <- call[ c( 1L, which( names(call) %in% names(formals(package.skeleton)))) ]
 
 	if( fake ){
-		call[["list"]] <- c( if( isTRUE(example_code)) "rcpp_hello_world" , "Rcpp.fake.fun" )
+		call[["list"]] <- c( if( isTRUE(example_code) && !isTRUE(attributes)) "rcpp_hello_world" , "Rcpp.fake.fun" )
 	}
 
 	tryCatch( eval( call, envir = env ), error = function(e){
@@ -129,21 +133,37 @@ Rcpp.package.skeleton <- function(
 		file.copy( file.path( skeleton, "Makevars.win" ), Makevars.win )
 		message( " >> added Makevars.win file with Rcpp settings" )
 	}
-
+	
+	if ( length(cpp_files) > 0L ) {
+		for (file in cpp_files) {
+			file.copy(file, src)
+			message( " >> copied ", file, " to src directory" )
+		}
+		compileAttributes(root)
+	}
+	
 	if( example_code ){
-		header <- readLines( file.path( skeleton, "rcpp_hello_world.h" ) )
-		header <- gsub( "@PKG@", name, header, fixed = TRUE )
-		writeLines( header , file.path( src, "rcpp_hello_world.h" ) )
-		message( " >> added example header file using Rcpp classes")
-
-		file.copy( file.path( skeleton, "rcpp_hello_world.cpp" ), src )
-		message( " >> added example src file using Rcpp classes")
-
-		rcode <- readLines( file.path( skeleton, "rcpp_hello_world.R" ) )
-		rcode <- gsub( "@PKG@", name, rcode, fixed = TRUE )
-		writeLines( rcode , file.path( root, "R", "rcpp_hello_world.R" ) )
-		message( " >> added example R file calling the C++ example")
-
+		if ( isTRUE( attributes ) ) {
+			file.copy( file.path( skeleton, "rcpp_hello_world_attributes.cpp" ), 
+								 file.path( src, "rcpp_hello_world.cpp" ) )
+			message( " >> added example src file using Rcpp attributes")
+			compileAttributes(root)
+			message( " >> compiled Rcpp attributes")
+		} else {
+			header <- readLines( file.path( skeleton, "rcpp_hello_world.h" ) )
+			header <- gsub( "@PKG@", name, header, fixed = TRUE )
+			writeLines( header , file.path( src, "rcpp_hello_world.h" ) )
+			message( " >> added example header file using Rcpp classes")
+			
+			file.copy( file.path( skeleton, "rcpp_hello_world.cpp" ), src )
+			message( " >> added example src file using Rcpp classes")
+			
+			rcode <- readLines( file.path( skeleton, "rcpp_hello_world.R" ) )
+			rcode <- gsub( "@PKG@", name, rcode, fixed = TRUE )
+			writeLines( rcode , file.path( root, "R", "rcpp_hello_world.R" ) )
+			message( " >> added example R file calling the C++ example")
+		}
+		
 		hello.Rd <- file.path( root, "man", "rcpp_hello_world.Rd")
 		unlink( hello.Rd )
 		file.copy(
