@@ -1,4 +1,4 @@
-# Copyright (C)        2010 Dirk Eddelbuettel and Romain Francois
+# Copyright (C) 2010 - 2011 Dirk Eddelbuettel and Romain Francois
 #
 # This file is part of Rcpp.
 #
@@ -27,3 +27,13 @@ test <- function( output = if( file.exists( "/tmp" ) ) "/tmp" else getwd() ){
 	system( cmd )
 }
 
+compile_unit_tests <- function( definitions, includes = "", cxxargs = "" ){
+    signatures <- lapply(definitions, "[[", 1L)
+    bodies <- lapply(definitions, "[[", 2L)
+    cxxfunction <- get( "cxxfunction", asNamespace("inline" ) )
+    fun <- cxxfunction( signatures, bodies, plugin = "Rcpp", 
+        includes = sprintf( "using namespace std;\n%s", paste( includes, collapse = "\n") ), 
+        cxxargs = cxxargs
+    )
+    fun
+}
