@@ -35,9 +35,9 @@ namespace traits{
 		typedef typename storage_type<RTYPE>::type storage_type ;
 		
 		r_vector_cache() : start(0){} ;
-		void update( const VECTOR& v ) {
-			start = ::Rcpp::internal::r_vector_start<RTYPE>(v.asSexp()) ;
-			RCPP_DEBUG_3( " cache<%d>::update( <%p> ), start = <%p>", RTYPE, reinterpret_cast<void*>(v.asSexp()),  reinterpret_cast<void*>(start) ) ;
+		inline void update( const VECTOR& v ) {
+		    start = ::Rcpp::internal::r_vector_start<RTYPE>(v.asSexp()) ;
+			RCPP_DEBUG_3( " cache<%d>::update( <%p> ), start = <%p>", RTYPE, reinterpret_cast<void*>(v.asSexp()),  reinterpret_cast<void*>(start) )
 		}
 		inline iterator get() const { return start; }
 		inline const_iterator get_const() const { return start; }
