@@ -29,12 +29,12 @@ if (.runThisTest) {
 		    std::vector<int>* v = new std::vector<int> ;
 		    v->push_back( 1 ) ;
 		    v->push_back( 2 ) ;
-
+        
 		    /* wrap the pointer as an external pointer */
 		    /* this automatically protected the external pointer from R garbage
 		       collection until p goes out of scope. */
-		    Rcpp::XPtr< std::vector<int> > p(v, true) ;
-
+		    Rcpp::XPtr< std::vector<int> > p(v) ;
+        
 		    /* return it back to R, since p goes out of scope after the return
 		       the external pointer is no more protected by p, but it gets
 		       protected by being on the R side */
@@ -54,7 +54,7 @@ if (.runThisTest) {
 		       and return something else to R, you need to protect the external
 		       pointer, by using the protect member function */
 		    Rcpp::XPtr< std::vector<int> > p(x) ;
-
+        
     		/* just return the front of the vector as a SEXP */
     		return( Rcpp::wrap( p->front() ) ) ;
     	', plugin = "Rcpp" )
